summaryrefslogtreecommitdiff
path: root/ext/js/comm/mecab.js
diff options
context:
space:
mode:
authorDarius Jahandarie <djahandarie@gmail.com>2023-11-12 02:16:11 +0000
committerGitHub <noreply@github.com>2023-11-12 02:16:11 +0000
commitd06029ea8c4244f40f9ddfeec5154f9ef2a4c053 (patch)
tree93f3e15603ec38faef01070475904c08d2e9280b /ext/js/comm/mecab.js
parentf263e994c6eca2438eaff79cb22f1b48fe14b7b2 (diff)
parent784dcd93b02443bc253e3af43ad0586a1add39c5 (diff)
Merge pull request #314 from starxeras/replace-yomichan
Replace all instances of yomichan
Diffstat (limited to 'ext/js/comm/mecab.js')
-rw-r--r--ext/js/comm/mecab.js8
1 files changed, 4 insertions, 4 deletions
diff --git a/ext/js/comm/mecab.js b/ext/js/comm/mecab.js
index 50f13ddf..c7314605 100644
--- a/ext/js/comm/mecab.js
+++ b/ext/js/comm/mecab.js
@@ -19,7 +19,7 @@
import {EventListenerCollection} from '../core.js';
/**
* This class is used to connect Yomichan to a native component that is
* used to parse text into individual terms.
*/
export class Mecab {
@@ -99,7 +99,7 @@ export class Mecab {
/**
* Gets the local API version being used.
* @returns {number} An integer representing the API version that Yomichan uses.
*/
getLocalVersion() {
return this._version;
@@ -219,7 +219,7 @@ export class Mecab {
}
async _setupPort2() {
- const port = chrome.runtime.connectNative('yomichan_mecab');
+ const port = chrome.runtime.connectNative('yomitan_mecab');
this._eventListeners.addListener(port.onMessage, this._onMessage.bind(this));
this._eventListeners.addListener(port.onDisconnect, this._onDisconnect.bind(this));
this._port = port;
@@ -228,7 +228,7 @@ export class Mecab {
const {version} = await this._invoke('get_version', {});
this._remoteVersion = version;
if (version !== this._version) {
- throw new Error(`Unsupported MeCab native messenger version ${version}. Yomichan supports version ${this._version}.`);
+ throw new Error(`Unsupported MeCab native messenger version ${version}. Yomitan supports version ${this._version}.`);
}
} catch (e) {
if (this._port === port) {
@@ -19,7 +19,7 @@
import {EventListenerCollection} from '../core.js';
/**
- * This class is used to connect Yomichan to a native component that is
+ * This class is used to connect Yomitan to a native component that is
* used to parse text into individual terms.
*/
@@ -99,7 +99,7 @@ export class Mecab {
/**
* Gets the local API version being used.
- * @returns {number} An integer representing the API version that Yomichan uses.
+ * @returns {number} An integer representing the API version that Yomitan uses.
*/
getLocalVersion() {